@@ -1,11 +1,8 @@
 package GraphViz2;
 
 use strict;
-use utf8;
 use warnings;
 use warnings  qw(FATAL utf8);    # Fatalize encoding glitches.
-use open      qw(:std :utf8);    # Undeclared streams in UTF-8.
-use charnames qw(:full :short);  # Unneeded in v5.16.
 
 use Capture::Tiny 'capture';
 
@@ -133,7 +130,7 @@ has valid_attributes =>
 	required => 0,
 );
 
-our $VERSION = '2.25';
+our $VERSION = '2.26';
 
 # -----------------------------------------------
 
@@ -745,9 +742,9 @@ sub run
 
 		if ($output_file)
 		{
-			open(OUT, '> :raw', $output_file) || die "Can't open(> $output_file): $!";
-			print OUT $stdout;
-			close OUT;
+			open(my $fh, '> :raw', $output_file) || die "Can't open(> $output_file): $!";
+			print $fh $stdout;
+			close $fh;
 
 			$self -> log(debug => "Wrote $output_file. Size: " . length($stdout) . ' bytes');
 		}
@@ -1713,6 +1710,11 @@ Since V 2.00, L<GraphViz2> incorporates a sample which produce graphs such as L<
 
 scripts/utf8.1.pl contains 'use utf8;' because of the utf8 characters embedded in the source code. You will need to do this.
 
+=head2 Why did you remove 'use utf8' from this file (in V 2.26)?
+
+Because it is global, i.e. it applies to all code in your program, not just within this module.
+Some modules you are using may not expect that. If you need it, just use it in your *.pl script.
+
 =head2 Why do I get 'Wide character in print...' when outputting to PNG but not SVG?
 
 As of V 2.02, you should not get this from GraphViz2. So, I suggest you study your own code very, very carefully :-(.
